aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorErlend Egeberg Aasland <erlend.aasland@innova.no>2021-01-06 01:02:43 +0100
committerGitHub <noreply@github.com>2021-01-06 02:02:43 +0200
commitcf0b23908cc902ac38cd83dd7ca5afdf89e1543b (patch)
tree213330fcd0db5954b3937e913a168fc7f68ebf4b /Modules/_sqlite/module.c
parentbpo-40956: Convert _sqlite3.Cursor to Argument Clinic (GH-24007) (diff)
downloadcpython-cf0b23908cc902ac38cd83dd7ca5afdf89e1543b.tar.gz
cpython-cf0b23908cc902ac38cd83dd7ca5afdf89e1543b.tar.bz2
cpython-cf0b23908cc902ac38cd83dd7ca5afdf89e1543b.zip
bpo-40810: Require SQLite 3.7.15 (GH-24106)
Diffstat (limited to 'Modules/_sqlite/module.c')
-rw-r--r--Modules/_sqlite/module.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/Modules/_sqlite/module.c b/Modules/_sqlite/module.c
index cd2eb576c7b..6bfb1b73f82 100644
--- a/Modules/_sqlite/module.c
+++ b/Modules/_sqlite/module.c
@@ -29,8 +29,8 @@
#include "microprotocols.h"
#include "row.h"
#if SQLITE_VERSION_NUMBER < 3007003
#error "SQLite 3.7.3 or higher required"
#endif
#include "clinic/module.c.h"
@@ -365,8 +365,8 @@ PyMODINIT_FUNC PyInit__sqlite3(void)
{
PyObject *module;
- if (sqlite3_libversion_number() < 3007003) {
- PyErr_SetString(PyExc_ImportError, MODULE_NAME ": SQLite 3.7.3 or higher required");
+ if (sqlite3_libversion_number() < 3007015) {
+ PyErr_SetString(PyExc_ImportError, MODULE_NAME ": SQLite 3.7.15 or higher required");
return NULL;
}
@@ -29,8 +29,8 @@
#include "microprotocols.h"
#include "row.h"
-#if SQLITE_VERSION_NUMBER < 3007003
-#error "SQLite 3.7.3 or higher required"
+#if SQLITE_VERSION_NUMBER < 3007015
+#error "SQLite 3.7.15 or higher required"
#endif
#include "clinic/module.c.h"